using System;

namespace StarDelta
{

	class StarDelta
	{
		double r1, r2, r3;	// the star resistances
		double ra, rb, rc;	// the delta resistances

		public StarDelta()
		{
			r1 = r2 = r3 = 1.0;
			StarToDelta();
		}

		public double R1 
		{
			get { return r1; }
			set { r1 = value; }
		}
		public double R2 
		{
			get { return r2; }
			set { r2 = value; }
		}
		public double R3 
		{
			get { return r3; }
			set { r3 = value; }
		}

		public double Ra 
		{
			get { return ra; }
			set { ra = value; }
		}
		public double Rb 
		{
			get { return rb; }
			set { rb = value; }
		}
		public double Rc 
		{
			get { return rc; }
			set { rc = value; }
		}


		// Star to Delta conversation

		public void StarToDelta()
		{
			ra = (r1*r2 + r2*r3 + r3*r1) / r3;
			rb = (r2*r3 + r3*r1 + r1*r2) / r1;
			rc = (r3*r1 + r1*r2 + r2*r3) / r2;
		}

		// Delta to Star conversation

		public void DeltaToStar()
		{
			r1 = ra*rc / ( ra + rb + rc );
			r2 = rb*ra / ( ra + rb + rc );
			r3 = rc*rb / ( ra + rb + rc );
		}

		void ShowValues()
		{
			Console.WriteLine("Star - circuit      Delta - circuit");
			Console.WriteLine("-----------------------------------------------------");
			Console.WriteLine("r1  = %8.2f Ohm  ra  = %8.2f Ohm", r1, ra);
			Console.WriteLine("r2  = %8.2f Ohm  rb  = %8.2f Ohm", r2, rb);
			Console.WriteLine("r3  = %8.2f Ohm  rc  = %8.2f Ohm", r3, rc);
			Console.WriteLine("-----------------------------------------------------");
			Console.WriteLine("R12 = %8.2f Ohm  R12 = %8.2f Ohm", RStar(1,2), RDelta(1,2));
			Console.WriteLine("R23 = %8.2f Ohm  R23 = %8.2f Ohm", RStar(2,3), RDelta(2,3));
			Console.WriteLine("R31 = %8.2f Ohm  R31 = %8.2f Ohm", RStar(3,1), RDelta(3,1));
			Console.WriteLine();
		}


		// Star-circuit
		// Calculate the resistance between the terminals i and j

		public double RStar (int i, int j)
		{
			if ( (i == 1 && j == 2) || (i == 2 && j == 1) ) 
				return r1 + r2;
			if ( (i == 2 && j == 3) || (i == 3 && j == 2) ) 
				return r2 + r3;
			if ( (i == 3 && j == 1) || (i == 1 && j == 3) ) 
				return r3 + r1;

			Console.WriteLine("Error in function RStar: illegal terminal numbers!\n");
			return 0.0;
		}

		// Delta-circuit
		// Calculate the resistance between the terminals i and j

		public double RDelta(int i, int j)
		{
			if ( (i == 1 && j == 2) || (i == 2 && j == 1) ) 
				return ra * (rb + rc) / (ra + rb + rc);
			if ( (i == 2 && j == 3) || (i == 3 && j == 2) ) 
				return rb * (rc + ra) / (ra + rb + rc);
			if ( (i == 3 && j == 1) || (i == 1 && j == 3) ) 
				return rc * (ra + rb) / (ra + rb + rc);

			Console.WriteLine("Error in function RStar: illegal terminal numbers!\n");
			return 0.0;
		}
	}
}
